function [cl,w] = clustercoeff_kaiser(matrix)
% [cl,w] = clustercoeff_kaiser(matrix)
% clustering coefficient
% cl: average over all nodes
% w: local values for each node
%
% Nodes with one or zero neighbours which would otherwise get a
% local clustering coefficient of zero are not included in the
% average calculation
% (Ref: Kaiser, New Journal of Physics, 2008)
%
% Author: Marcus Kaiser  Date: 08 July 2007

NODES=length(matrix);


    w=zeros(NODES,1);
    n_neigh = 0; % number of nodes with at least two neighbors
    for i=1:NODES
     n = find(matrix(i,:)+matrix(:,i)');
     n_e = 0;
     l_n = length(n);
     for j=1:l_n
       [dummy,n_v,dummy2] = find(matrix(n(j),:));
       n_e = n_e + l_n + length(n_v) - length(union(n,n_v));
     end;
     if l_n>1
       w(i) = n_e/(l_n*(l_n-1));
       n_neigh = n_neigh + 1;
     end;
    end;
    cl=sum(w)/n_neigh;


return
