function [cl,w] = clustercoeff_newman(matrix)
% [cl,w] = clustercoeff_newman(matrix)
% clustering coefficient
% cl: average over all nodes
% w: local values for each node
%
% definition according to
% Newman, Strogatz & Watts, Phys. Rev. E, 2001
%
% Author: Marcus Kaiser  Date: 30 June 2007

NODES=length(matrix);
    cnt = 0;

    w=zeros(NODES,1);
    w_pot=zeros(NODES,1);
    for i=1:NODES
     n = find(matrix(i,:)+matrix(:,i)');
     n_e=0;
     l_n=length(n);
     for j=1:l_n
       [dummy,n_v,dummy2]=find(matrix(n(j),:));
       n_e=n_e+l_n+length(n_v)-length(union(n,n_v));
     end;
     w(i)=n_e;
     w_pot(i)=(l_n*(l_n-1));
    end;
    cl=sum(w)/sum(w_pot);


return
