function [dis,w] = disconnectedness(matrix)
% [dis,w] = disconnectedness(matrix)
% disconnectedness
% D = 1/N * \sum_i{1/C_i}
% where C_i is the local clustering coefficient
% (1/C_i := 0 if a node has no neighbors)
% dis: average over all nodes
% w: local values for each node
%
% for more information see
% Kaiser, New Journal of Physics, 2008
%
% Author: Marcus Kaiser  Date: 25 July 2008

NODES = length(matrix);
w = zeros(NODES,1);

for i = 1:NODES
    n = find(matrix(i,:)+matrix(:,i)');
    n_e = 0;
    l_n = length(n);
    for j = 1:l_n
        [dummy,n_v] = find(matrix(n(j),:));
        n_e = n_e + l_n + length(n_v) - length(union(n,n_v));
    end;
    if n_e > 0
        w(i) = (l_n*(l_n-1)) / (n_e);
    else
        w(i) = 0;
    end;
end;
dis = sum(w) / NODES;

return
