function sw = smallworldgraph_inverse(n,e)
% sw = smallworldgraph_inverse(n,e)
% yields matrix of a small-world graph
% with n nodes and e edges
% Instead of the Watts & Strogatz, 1998 approach
% the generation starts with a random network (not a lattice)
% at each step:
% before:    A->B        D->E
%            find edge AB and node C which is not yet connected to D or E
% after:     A  B     C->D->E
%            remove edge AB and establish edge CD
%
% reference for more information:
% Kaiser, New Journal of Physics, 2008
%
% Author: Marcus Kaiser  Date: 26 May 2008

% constants
prob = 10; % was 0.25
             % 0.1 for mac73

% generate initial matrix (p=1)
sw = randomgraph(n,e);
[i,j] = find(sw);
sw0 = ones(n)-sw-diag(ones(n,1),0);
swnoneigh = cell(n,1);
for k=1:n
    swnoneigh{k} = find(sw0(k,:));
end;
c = 0;

% rewiring (p=prob)
while c<prob*e
    r = ceil(length(i).*rand(2));
    r2 = ceil(length(swnoneigh{i(r(2))}).*rand(1));
    sw(i(r(1)), j(r(1))) = 0;
    sw(i(r(2)), swnoneigh{i(r(2))}(r2)) = 1;
    i(r(1)) = i(r(2));
    j(r(1)) = swnoneigh{i(r(2))}(r2);
    c = c + 1;
end;
